package info.aspirecn.iov.sjjh.supplier10000043.action;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import info.aspirecn.iov.sjjh.commons.lang.ChannelTypeHandleResponseObject;
import info.aspirecn.iov.sjjh.commons.lang.Constant;
import info.aspirecn.iov.sjjh.supplier10000043.constant.SjjhConstant;
import info.aspirecn.iov.sjjh.supplier10000043.service.ChannelService;
import info.aspirecn.rdc.aspirecloud.node.except.utils.ErrorUtils;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import lombok.extern.slf4j.Slf4j;
import org.apache.tomcat.util.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;

/**
 * @description:
 * @author: xusonglin
 * @create: 2020/6/15 15:58
 * @version: V1.0
 **/
@Slf4j
@RestController
public class ChannelAction {
    @Autowired
    ChannelService channelService;

    @ApiOperation(value = "身份证二要素接口", notes = "")
    @PostMapping(value = "/twoElementsCheck.do")
    public ChannelTypeHandleResponseObject twoElementsCheck(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用servicevalidateCompositeIdentityInfo
        ChannelTypeHandleResponseObject ret = channelService.twoElementsCheck(request, customBody, outTime, SjjhConstant.DECODE_TYPE_COMMON);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(SjjhConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("twoElementsCheck.encodeBase64String.Exception={}", ex);
        }
        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }
    @ApiOperation(value = "身份证二要素接口-new", notes = "")
    @PostMapping(value = "/twoElementsCheckNew.do")
    public ChannelTypeHandleResponseObject twoElementsCheckNew(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用servicevalidateCompositeIdentityInfo
        ChannelTypeHandleResponseObject ret = channelService.twoElementsCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_COMMON);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(SjjhConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("twoElementsCheck.encodeBase64String.Exception={}", ex);
        }
        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }
    @ApiOperation(value = "人像接口", notes = "")
    @PostMapping(value = "/photoIdentityCheck.do")
    public ChannelTypeHandleResponseObject photoIdentityCheck(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheck(request, customBody, outTime, SjjhConstant.DECODE_TYPE_COMMON);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }


    @ApiOperation(value = "人像接口-new", notes = "")
    @PostMapping(value = "/photoIdentityCheckNew.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckNew(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_COMMON);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "身份证二要素接口(微众加密)", notes = "")
    @PostMapping(value = "/twoElementsCheckWeiZhong.do")
    public ChannelTypeHandleResponseObject twoElementsCheckWeiZhong(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.twoElementsCheck(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(SjjhConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("twoElementsCheckWeiZhong.encodeBase64String.Exception={}", ex);
        }
        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "身份证二要素接口(微众加密)", notes = "")
    @PostMapping(value = "/twoElementsCheckWeiZhongNew.do")
    public ChannelTypeHandleResponseObject twoElementsCheckWeiZhongNew(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.twoElementsCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(SjjhConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("twoElementsCheckWeiZhong.encodeBase64String.Exception={}", ex);
        }
        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }
    @ApiOperation(value = "人像接口（微众加密）", notes = "")
    @PostMapping(value = "/photoIdentityCheckWeiZhong.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckWeiZhong(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheck(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "人像接口（微众加密）", notes = "")
    @PostMapping(value = "/photoIdentityCheckWeiZhongNew.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckWeiZhongNew(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }
    @ApiOperation(value = "人像接口-v2", notes = "")
    @PostMapping(value = "/photoIdentityCheckV2.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV2(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckV2(request, customBody, outTime, SjjhConstant.DECODE_TYPE_COMMON);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "人像接口-v2", notes = "")
    @PostMapping(value = "/photoIdentityCheckV2CommonNew.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV2CommonNew(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckV2New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_COMMON);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }
    @ApiOperation(value = "人像接口-v2-WeiZhong解密", notes = "")
    @PostMapping(value = "/photoIdentityCheckWeiZhongV2.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckWeiZhongV2(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckV2(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }


    @ApiOperation(value = "人像接口（微众加密）", notes = "")
    @PostMapping(value = "/photoIdentityCheckWeiZhong2.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV2New(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = false) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody
            ) {

        try {
            HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                    .getRequest();
           //调用service
            ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckV2New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);

            //把接口参数、调用结果和是否收费放入访问日志中
            if (ret.getCode() != Constant.SUCCESS) {
                request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
            } else {
                request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
            }
            request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

            request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
            return ret;
        }catch (Exception ex){
            log.info("ex:{}",ex);
        }
        return null;
    }

    /*****************************************************/
    // 人像-中心-MD5版
    @ApiOperation(value = "人像接口-中心-MD5", notes = "")
    @PostMapping(value = "/photoIdentityCheckMD5.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckMD5(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_MD5);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    // 人像-中心-SHA256版
    @ApiOperation(value = "人像接口-中心-SHA256", notes = "")
    @PostMapping(value = "/photoIdentityCheckSHA256.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckSHA256(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_SHA256);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    // 人像-家政-MD5版
    @ApiOperation(value = "人像接口-家政-MD5", notes = "")
    @PostMapping(value = "/photoIdentityCheckV2MD5.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV2MD5(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = false) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody
    ) {

        try {
            HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                    .getRequest();
            //调用service
            ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckV2New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_MD5);

            //把接口参数、调用结果和是否收费放入访问日志中
            if (ret.getCode() != Constant.SUCCESS) {
                request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
            } else {
                request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
            }
            request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

            request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
            return ret;
        }catch (Exception ex){
            log.info("ex:{}",ex);
        }
        return null;
    }

    // 人像-家政-SHA256版
    @ApiOperation(value = "人像接口-家政-SHA256", notes = "")
    @PostMapping(value = "/photoIdentityCheckV2SHA256.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV2SHA256(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = false) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody
    ) {

        try {
            HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                    .getRequest();
            //调用service
            ChannelTypeHandleResponseObject ret = channelService.photoIdentityCheckV2New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_SHA256);

            //把接口参数、调用结果和是否收费放入访问日志中
            if (ret.getCode() != Constant.SUCCESS) {
                request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
            } else {
                request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
            }
            request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

            request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
            return ret;
        }catch (Exception ex){
            log.info("ex:{}",ex);
        }
        return null;
    }

    // 二要素-中心-MD5版
    @ApiOperation(value = "身份证二要素接口-中心-MD5", notes = "")
    @PostMapping(value = "/twoElementsCheckNewMD5.do")
    public ChannelTypeHandleResponseObject twoElementsCheckNewMD5(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.twoElementsCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_MD5);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(SjjhConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("twoElementsCheckNewMD5.encodeBase64String.Exception={}", ex);
        }
        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    // 二要素-中心-SHA256版
    @ApiOperation(value = "身份证二要素接口-中心-SHA256", notes = "")
    @PostMapping(value = "/twoElementsCheckNewSHA256.do")
    public ChannelTypeHandleResponseObject twoElementsCheckNewSHA256(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret = channelService.twoElementsCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_SHA256);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(SjjhConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("twoElementsCheckNewSHA256.encodeBase64String.Exception={}", ex);
        }
        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    /*******************************************/

    @ApiOperation(value = "家政人像接口（微众加密）-AES", notes = "")
    @PostMapping(value = "/photoIdentityCheckWeiZhong2AES.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckWeiZhong2AES(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = false) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody
    ) {

        try {
            HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                    .getRequest();
            //调用service
            ChannelTypeHandleResponseObject ret;
            JSONObject jsonObject = JSON.parseObject(customBody);
            if (jsonObject.get("type") != null && jsonObject.get("type").equals("1")) {
                ret = channelService.photoIdentityCheckV2New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_AES);
            } else {
                ret = channelService.photoIdentityCheckV2New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);
            }
            jsonObject = null;

            //把接口参数、调用结果和是否收费放入访问日志中
            if (ret.getCode() != Constant.SUCCESS) {
                request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
            } else {
                request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
            }
            request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

            request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
            return ret;
        }catch (Exception ex){
            log.info("ex:{}",ex);
        }
        return null;
    }

    @ApiOperation(value = "中心人像接口（微众加密）-AES", notes = "")
    @PostMapping(value = "/photoIdentityCheckWeiZhongNewAES.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckWeiZhongNewAES(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret;
        JSONObject jsonObject = JSON.parseObject(customBody);
        if (jsonObject.get("type") != null && jsonObject.get("type").equals("1")) {
            ret = channelService.photoIdentityCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_AES);
        } else {
            ret = channelService.photoIdentityCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);
        }
        jsonObject = null;

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "北轻人像接口（微众加密）-AES", notes = "")
    @PostMapping(value = "/photoIdentityCheckV3WeiZhongAES.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV3WeiZhongAES(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret;
        JSONObject jsonObject = JSON.parseObject(customBody);
        if (jsonObject.get("type") != null && jsonObject.get("type").equals("1")) {
            ret = channelService.photoIdentityCheckV3New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_AES);
        } else {
            ret = channelService.photoIdentityCheckV3New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);
        }
        jsonObject = null;

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "身份证二要素接口-new-aes", notes = "")
    @PostMapping(value = "/twoElementsCheckNewAES.do")
    public ChannelTypeHandleResponseObject twoElementsCheckNewAES(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用servicevalidateCompositeIdentityInfo
        ChannelTypeHandleResponseObject ret = channelService.twoElementsCheckNew(request, customBody, outTime, SjjhConstant.DECODE_TYPE_AES);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(SjjhConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("twoElementsCheck.encodeBase64String.Exception={}", ex);
        }
        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "英泰思特人像接口（微众加密）-AES", notes = "")
    @PostMapping(value = "/photoIdentityCheckV4WeiZhongAES.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV4WeiZhongAES(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret;
        JSONObject jsonObject = JSON.parseObject(customBody);
        if (jsonObject.get("type") != null && jsonObject.get("type").equals("1")) {
            ret = channelService.photoIdentityCheckV4New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_AES);
        } else {
            ret = channelService.photoIdentityCheckV4New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);
        }
        jsonObject = null;

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "榕树人像接口（微众加密）-AES", notes = "")
    @PostMapping(value = "/photoIdentityCheckV5WeiZhongAES.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV5WeiZhongAES(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret;
        JSONObject jsonObject = JSON.parseObject(customBody);
        if (jsonObject.get("type") != null && jsonObject.get("type").equals("1")) {
            ret = channelService.photoIdentityCheckV5New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_AES);
        } else {
            ret = channelService.photoIdentityCheckV5New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);
        }
        jsonObject = null;

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "榕树人像接口V2（微众加密）-AES", notes = "")
    @PostMapping(value = "/photoIdentityCheckV6WeiZhongAES.do")
    public ChannelTypeHandleResponseObject photoIdentityCheckV6WeiZhongAES(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestBody String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用service
        ChannelTypeHandleResponseObject ret;
        JSONObject jsonObject = JSON.parseObject(customBody);
        if (jsonObject.get("type") != null && jsonObject.get("type").equals("1")) {
            ret = channelService.photoIdentityCheckV6New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_AES);
        } else {
            ret = channelService.photoIdentityCheckV6New(request, customBody, outTime, SjjhConstant.DECODE_TYPE_WEIZHONG);
        }
        jsonObject = null;

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }

    @ApiOperation(value = "BQ身份证二要素接口-new", notes = "")
    @PostMapping(value = "/twoElementsCheckV2.do")
    public ChannelTypeHandleResponseObject twoElementsCheckV2(
            @ApiParam(value = "通道ID") @RequestHeader(name = "channelId") String channelId,
            @ApiParam(value = "超时时间,单位：毫秒", example = "10000") @RequestParam(name = "outTime", required = true) int outTime,
            @ApiParam(value = "请求参数JSON串") @RequestParam(name = "customBody", required = true) String customBody) {
        HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes())
                .getRequest();

        //调用servicevalidateCompositeIdentityInfo
        ChannelTypeHandleResponseObject ret = channelService.twoElementsCheckV2(request, customBody, outTime, SjjhConstant.DECODE_TYPE_COMMON);

        //把接口参数、调用结果和是否收费放入访问日志中
        if (ret.getCode() != Constant.SUCCESS) {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_ERROR_CODE);
        } else {
            request.setAttribute(SjjhConstant.Charge_Log_ResponseCode, Constant.CHANNEL_LOG_SUCCESS_CODE);
        }
        request.setAttribute(SjjhConstant.Charge_Log_Key, ret.getIsCharge());

        try {
            request.setAttribute(Constant.CHANNEL_LOG_QUERY,
                    Base64.encodeBase64String(customBody.getBytes(SjjhConstant.PARA_ENCODE)));

        } catch (Exception ex) {
            ErrorUtils.captureException(ex);
            log.error("twoElementsCheckV2.encodeBase64String.Exception=", ex);
        }
        request.setAttribute(Constant.CHANNEL_TYPE_KEY, Constant.CHANNEL_TYPE_SYNC);
        return ret;
    }
}
